a dataset of population by municipality of mexico. dataset ...

pop2000

Format

## `pop2000` A data frame with 2443 rows and 4 columns:

CVEGEO

id of the municipality.

pobtot

population

pobfem

female population

pobmas

male population

...

<https://www.inegi.org.mx/app/scitel/Default?ev=9>

Details

The population data by total number and sex for each municipality were obtained from the dataset of territorial indicators known as ITER /(Indicadores Territoriales/), which is a database derived from the 2020 Population and Housing Census generated by Instituto Nacional de Estadística y Geografía (INEGI)