a dataset of population by municipality of mexico. dataset ...
pop2000## `pop2000` A data frame with 2443 rows and 4 columns:
id of the municipality.
population
female population
male population
<https://www.inegi.org.mx/app/scitel/Default?ev=9>
The population data by total number and sex for each municipality were obtained from the dataset of territorial indicators known as ITER /(Indicadores Territoriales/), which is a database derived from the 2020 Population and Housing Census generated by Instituto Nacional de Estadística y Geografía (INEGI)